@@ -61,7 +61,11 @@ pub trait MixedNum
     fn mixed_powi( &self, exp: i32 ) -> Self;
     /// Get the sign of the argument with a unit value.
     /// Zero is of positive sign.
-    fn sign( &self ) -> Self;
+    fn mixed_sign( &self ) -> Self;
+    /// Returns a bool if self is positive.
+    fn mixed_is_positive( &self ) -> bool;
+    /// Returns a bool if self is negative.
+    fn mixed_is_negative( &self ) -> bool;
 }
 
 pub trait MixedNumSigned
@@ -159,9 +163,17 @@ macro_rules! impl_mixed_num_for_primitive{
             fn mixed_powi( &self, exp: i32 ) -> Self {
                 return self.powi( exp );
             }
-            fn sign( &self) -> Self {
+            fn mixed_sign( &self) -> Self {
                 return trigonometry::sign(*self);
             }
+            #[inline(always)]
+            fn mixed_is_positive( &self) -> bool {
+                return self.is_sign_positive();
+            }
+            #[inline(always)]
+            fn mixed_is_negative( &self) -> bool {
+                return self.is_sign_negative();
+            }
         }
 
         impl MixedConsts for $T
@@ -261,9 +273,17 @@ macro_rules! impl_mixed_num_for_fixed_unsigned{
                 return trig::powi( *self, exp as usize );
             }
             #[inline(always)]
-            fn sign( &self) -> Self {
+            fn mixed_sign( &self) -> Self {
                 return trigonometry::sign(*self);
             }
+            #[inline(always)]
+            fn mixed_is_positive( &self) -> bool {
+                return true;
+            }
+            #[inline(always)]
+            fn mixed_is_negative( &self) -> bool {
+                return false;
+            }
         }
     }
 }
@@ -290,9 +310,18 @@ macro_rules! impl_mixed_num_for_fixed_signed{
             fn mixed_powi( &self, exp: i32 ) -> Self {
                 return trig::powi( *self, exp as usize );
             }
-            fn sign( &self) -> Self {
+            #[inline(always)]
+            fn mixed_sign( &self) -> Self {
                 return trigonometry::sign(*self);
             }
+            #[inline(always)]
+            fn mixed_is_positive( &self) -> bool {
+                return self.is_positive();
+            }
+            #[inline(always)]
+            fn mixed_is_negative( &self) -> bool {
+                return self.is_negative();
+            }
         }
     }
 }
